@@ -444,6 +444,11 @@
 (defun mew-inbox-action-alist (&optional case)
   (mew-cfent-value case "inbox-action-alist" mew-inbox-action-alist))
 
+;;
+
+(defun mew-draft-privacy-method (&optional case)
+  (mew-cfent-value case "draft-privacy-method" mew-draft-privacy-method))
+
 ;;;
 ;;; Setting case
 ;;;
@@ -560,7 +565,7 @@ fields in the header according to the new value."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2006 Mew developing team.
+;; Copyright (C) 1999-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
