@@ -599,7 +599,7 @@ Return a part syntax after moving the beginning of the content body."
 	 (ct (mew-syntax-get-value ctl 'cap))
 	 (textp (mew-ct-textp ct))
 	 (cte (or (mew-syntax-get-cte syntax) mew-7bit))
-	 (multi-err t) (encap nil) type)
+	 (multi-err t) (encap nil) type hend)
     ;; the beginning of the content body
     (cond
      ((not (mew-cte-p cte))
@@ -677,13 +677,16 @@ Return a part syntax after moving the beginning of the content body."
     ;; or single in multipart/alternative
     ;; or single in multipart/security
     (setq type (mew-syntax-get-value (mew-syntax-get-ct syntax) 'cap))
-    (unless (mew-syntax-get-end syntax)
+    (setq hend (mew-syntax-get-end syntax))
+    (unless hend
       (mew-syntax-set-end syntax (point-max)))
     (when (and (string= type mew-ct-txt)
 	       ;; highlight in the cache buffers only
 	       (string-match mew-buffer-cache-prefix (buffer-name)))
       (mew-highlight-body-region (mew-syntax-get-begin syntax)
 				 (mew-syntax-get-end syntax)))
+    (unless hend
+      (mew-syntax-set-end syntax (point-max))) ;; ajusting
     (if encap
 	;; Mew allows text/plain and multipart/* for body.
 	;; If other CT: is embedded under message, it should be
@@ -993,7 +996,7 @@ Return a part syntax after moving the beginning of the content body."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
