@@ -997,52 +997,52 @@ Set privacy service which will be effective when \\[mew-draft-make-message]."
   "Sign the entire draft. Input your passphrase."
   (interactive "P")
   (cond
-   ((eq mew-draft-privacy-method 'pgp)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'pgp)
     (mew-pgp-sign-message arg))
-   ((eq mew-draft-privacy-method 'smime)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'smime)
     (mew-smime-sign-message arg))
    (t
-    (message "'%s' is not supported" mew-draft-privacy-method))))
+    (message "'%s' is not supported" (mew-draft-privacy-method (mew-tinfo-get-case))))))
 
 (defun mew-draft-encrypt-message ()
   "Encrypt the entire draft with PGP."
   (interactive)
   (cond
-   ((eq mew-draft-privacy-method 'pgp)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'pgp)
     (mew-pgp-encrypt-message))
-   ((eq mew-draft-privacy-method 'smime)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'smime)
     (mew-smime-encrypt-message))
    (t
-    (message "'%s' is not supported" mew-draft-privacy-method))))
+    (message "'%s' is not supported" (mew-draft-privacy-method (mew-tinfo-get-case))))))
 
 (defun mew-draft-sign-encrypt-message (&optional arg)
   "Sign then encrypt the entire draft. Input your passphrase."
   (interactive "P")
   (cond
-   ((eq mew-draft-privacy-method 'pgp)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'pgp)
     (mew-pgp-sign-encrypt-message arg))
-   ((eq mew-draft-privacy-method 'smime)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'smime)
     (mew-smime-sign-encrypt-message arg))
    (t
-    (message "'%s' is not supported" mew-draft-privacy-method))))
+    (message "'%s' is not supported" (mew-draft-privacy-method (mew-tinfo-get-case))))))
 
 
 (defun mew-draft-encrypt-sign-message (&optional arg)
   "Encrypt then sign the entire draft. Input your passphrase."
   (interactive "P")
   (cond
-   ((eq mew-draft-privacy-method 'pgp)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'pgp)
     (mew-pgp-encrypt-sign-message arg))
-   ((eq mew-draft-privacy-method 'smime)
+   ((eq (mew-draft-privacy-method (mew-tinfo-get-case)) 'smime)
     (mew-smime-encrypt-sign-message arg))
    (t
-    (message "'%s' is not supported" mew-draft-privacy-method))))
+    (message "'%s' is not supported" (mew-draft-privacy-method (mew-tinfo-get-case))))))
 
 (provide 'mew-draft)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
