@@ -297,7 +297,9 @@
   (define-key mew-message-mode-map "r"    'mew-message-resend)
   (define-key mew-message-mode-map "k"	  (make-sparse-keymap))
   (define-key mew-message-mode-map "kp"   'mew-nmz-search-msgid-at-point)
-  (define-key mew-message-mode-map "kr"   'mew-nmz-search-msgid-region))
+  (define-key mew-message-mode-map "kr"   'mew-nmz-search-msgid-region)
+  (define-key mew-message-mode-map "g"    'mew-browse-url-at-point)
+  (define-key mew-message-mode-map "\C-i" 'mew-message-goto-next-url))
 
 (defvar mew-message-mode-menu-spec
   '("Mew"
@@ -651,7 +653,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2006 Mew developing team.
+;; Copyright (C) 2000-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
