@@ -508,7 +508,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
     (setq process
 	  (apply 'mew-start-process-lang
 		 "PGP sign"
-		 (current-buffer)
+		 (current-buffer) ;; xxx nil?
 		 pgps
 		 (append soptions (list loption mew-inherit-encode-signer ooption file2 file1))))
     (mew-set-process-cs process mew-cs-autoconv mew-cs-dummy)
@@ -692,13 +692,13 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   (interactive "P")
   (mew-pgp-encode-message 'pgp-encryption-signature))
 
-(defun mew-pgp-encode-message (type &optional ask-singer)
+(defun mew-pgp-encode-message (type &optional ask-signer)
   (if (null mew-pgp-ver)
       (message "%s does not exist" mew-prog-pgp)
     (let ((func 'mew-draft-make-message))
       (if (mew-use-old-pgp (mew-tinfo-get-case))
 	  (setq func 'mew-old-pgp-encode))
-      (if (and ask-singer (string-match "signature" (symbol-name type)))
+      (if (and ask-signer (string-match "signature" (symbol-name type)))
 	  (funcall func type (car (mew-input-address "Who's key?: ")))
 	(funcall func type)))))
 
@@ -1240,7 +1240,7 @@ according to a URL in a field specified by 'mew-x-pgp-key-list'."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2006 Mew developing team.
+;; Copyright (C) 1994-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
