@@ -77,7 +77,7 @@
 		  "Auth'ing"
 		  nil
 		  (mew-pop-secure-p pnm))
-  (if (re-search-forward "<[^<>]+@[^<>]+>" nil t)
+  (if (re-search-forward "<[=!-;?-~]+@[=!-;?-~]+>" nil t)
       (mew-pop-set-key pnm (mew-match-string 0)))
   (mew-pop-process-send-string pro "CAPA"))
 
@@ -957,7 +957,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2006 Mew developing team.
+;; Copyright (C) 1999-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
