@@ -34,7 +34,7 @@
      mew-google-index-folder mew-google-index-all
      mew-pick-canonicalize-pattern-google
      mew-google-register mew-google-unregister)
-    (est "Hyperestraier" ,mew-prog-est
+    (est "Hyper Estraier" ,mew-prog-est
      mew-search-with-est mew-search-virtual-with-est
      mew-est-index-folder mew-est-index-all
      mew-pick-canonicalize-pattern-est
@@ -302,15 +302,16 @@ with a search method."
       (setq flds (cdr flds))
       (mew-search-spotlight pattern path)
       (goto-char (point-min))
-      (while (looking-at regex)
-	(setq rttl (1+ rttl))
-	(setq crnt (match-string 1))
-	(delete-region (match-beginning 0) (match-beginning 2))
-	(when (not (string= crnt prev))
-	  (beginning-of-line)
-	  (insert "CD:" mew-folder-local crnt "\n"))
-	(setq prev crnt)
-	(forward-line))
+      (while (not (eobp))
+	(when (looking-at regex)
+	  (setq rttl (1+ rttl))
+	  (setq crnt (match-string 1))
+	  (delete-region (match-beginning 0) (match-beginning 2))
+	  (when (not (string= crnt prev))
+	    (beginning-of-line)
+	    (insert "CD:" mew-folder-local crnt "\n"))
+	  (setq prev crnt)
+	  (forward-line)))
       (mew-frwlet
        mew-cs-text-for-read mew-cs-text-for-write
        (write-region (point-min) (point-max) file (> n 1) 'no-msg))
@@ -395,15 +396,16 @@ with a search method."
 	 crnt)
     (mew-search-google pattern path)
     (goto-char (point-min))
-    (while (looking-at regex)
-      (setq rttl (1+ rttl))
-      (setq crnt (match-string 1))
-      (delete-region (match-beginning 0) (match-beginning 2))
-      (when (not (string= crnt prev))
-	(beginning-of-line)
-	(insert "CD:" mew-folder-local crnt "\n"))
-      (setq prev crnt)
-      (forward-line))
+    (while (not (eobp))
+      (when (looking-at regex)
+	(setq rttl (1+ rttl))
+	(setq crnt (match-string 1))
+	(delete-region (match-beginning 0) (match-beginning 2))
+	(when (not (string= crnt prev))
+	  (beginning-of-line)
+	  (insert "CD:" mew-folder-local crnt "\n"))
+	(setq prev crnt)
+	(forward-line)))
     (mew-frwlet
      mew-cs-text-for-read mew-cs-text-for-write
      (write-region (point-min) (point-max) file nil 'no-msg))
@@ -477,14 +479,15 @@ with a search method."
 	 crnt)
     (mew-search-wds pattern path)
     (goto-char (point-min))
-    (while (looking-at regex)
-      (setq rttl (1+ rttl))
-      (setq crnt (match-string 1))
-      (delete-region (match-beginning 0) (match-beginning 2))
-      (when (not (string= crnt prev))
-	(beginning-of-line)
-	(insert "CD:" mew-folder-local crnt "\n"))
-      (setq prev crnt)
+    (while (not (eobp))
+      (when (looking-at regex)
+	(setq rttl (1+ rttl))
+	(setq crnt (match-string 1))
+	(delete-region (match-beginning 0) (match-beginning 2))
+	(when (not (string= crnt prev))
+	  (beginning-of-line)
+	  (insert "CD:" mew-folder-local crnt "\n"))
+	(setq prev crnt))
       (forward-line))
     (mew-frwlet
      mew-cs-text-for-read mew-cs-text-for-write
@@ -533,42 +536,51 @@ with a search method."
 ;;;
 
 (defun mew-est-input-filter ()
-  (read-string "Hyperestraier filter: "))
+  (read-string "Hyper Estraier filter: "))
 
 (defvar mew-search-est-db "casket")
 (defvar mew-prog-est-update "mewest")
 
 (defun mew-search-est (pattern path filter)
-  (setq pattern (mew-cs-encode-string pattern 'utf-8))
+  (setq pattern (mew-cs-encode-string pattern mew-cs-est))
   (if (string= filter "")
       (setq filter nil)
-    (setq filter (mew-cs-encode-string filter 'utf-8))
+    (setq filter (mew-cs-encode-string filter mew-cs-est))
     (setq filter (let ((mew-inherit-pick-omit-and t))
 		   (mew-pick-parse (mew-pick-lex filter))))
     (setq filter (mapcar 'mew-pick-filter-est-kyvl filter)))
   (let* ((ent (mew-search-get-ent mew-search-method))
 	 (prog (mew-search-get-prog ent))
 	 (casket (expand-file-name mew-search-est-db mew-conf-path))
-	 maildir len attr args)
-    (mew-plet
-     (mew-alet
-      (setq maildir (file-truename (expand-file-name mew-home)))
-      (setq len (length (file-name-as-directory maildir)))
-      (setq path (substring (file-truename path) len))
-      (setq path (file-name-as-directory path))
-      (setq attr (format "@uri STRINC %s" (mew-q-encode-string path ?%)))
-      (cond
-       ((string-match "^ *ANDNOT " pattern)
-	(setq pattern (concat "[UVSET] " pattern)))
-       ((string-match "^ *$" pattern)
-	(setq pattern "[UVSET]")))
-      (setq args (list "-vu" "-max" "-1" "-ord" "@cdate NUMA" casket pattern))
-      (setq filter (nreverse filter))
-      (while filter
-	(setq args (cons "-attr" (cons (car filter) args)))
-	(setq filter (cdr filter)))
-      (setq args (cons "-attr" (cons attr args)))
-      (apply 'call-process prog nil t nil "search" args)))))
+	 ;; mew-home is not good for Zaurus
+	 (pregex (concat "^"
+			 (regexp-quote
+			  (file-name-directory
+			   (directory-file-name
+			    (file-truename
+			     (expand-file-name mew-mail-path)))))))
+	 attr args)
+    (setq path (file-truename (file-name-as-directory path)))
+    (when (string-match pregex path)
+      (setq path (substring path (match-end 0)))
+      (mew-plet
+       (mew-alet
+	(setq attr (format "@uri STRINC %s" (mew-q-encode-string path ?%)))
+	(cond
+	 ((string-match "^ *ANDNOT " pattern)
+	  (setq pattern (concat "[UVSET] " pattern)))
+	 ((string-match "^ *$" pattern)
+	  (setq pattern "[UVSET]")))
+	(setq args (list "-vu" "-max" "-1" "-ord" "@cdate NUMA" casket pattern))
+	(unless (eq mew-cs-est 'utf-8)
+	  (setq args (cons (mew-cs-to-charset mew-cs-est) args))
+	  (setq args (cons "-ic" args)))
+	(setq filter (nreverse filter))
+	(while filter
+	  (setq args (cons "-attr" (cons (car filter) args)))
+	  (setq filter (cdr filter)))
+	(setq args (cons "-attr" (cons attr args)))
+	(apply 'call-process prog nil t nil "search" args))))))
 
 (defun mew-search-with-est (pattern folder filter)
   (let* ((path (mew-expand-folder folder))
@@ -647,7 +659,9 @@ with a search method."
     (message "Another Hyper Estraier indexer is running"))
    ((string-match "\.\.\.failed" string)
     (message "Hyper Estraier indexing ...failed"))
-   ((string-match "\.\.\.done" string)
+   ((string-match "old messages\.\.\.done" string)
+    (message "Hyper Estraier purging ...done"))
+   ((string-match "new messages\.\.\.done" string)
     (message "Hyper Estraier indexing ...done"))))
 
 (defun mew-est-index-sentinel (process event)
@@ -657,7 +671,7 @@ with a search method."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2005-2006 Mew developing team.
+;; Copyright (C) 2005-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
