@@ -523,7 +523,7 @@ If called with '\\[universal-argument]', it stays writable."
    (let* ((win (selected-window))
 	  (fld (mew-summary-folder-name))
 	  (msg (mew-summary-message-number2))
-	  lst ent svr-date snd rcv svr date tmp)
+	  lst ent svr-date (snd "?") (rcv "?") last svr date tmp)
      (mew-summary-set-message-buffer fld msg)
      ;; message buffer or cache buffer
      (setq lst (nreverse (mew-header-get-value mew-received: 'as-list)))
@@ -546,10 +546,12 @@ If called with '\\[universal-argument]', it stays writable."
 	 (cond
 	  ((string-match "(\\(qmail [0-9]+\\)" svr)
 	   (setq rcv (match-string 1 svr)))
-	  ((string-match "by[ \t]*\\([^() \t\n]+\\)" svr)
+	  ((string-match "by[ \t]+\\([^() \t\n]+\\)" svr)
 	   (setq rcv (match-string 1 svr))
-	   (if (string-match "from[ \t]*\\([^() \t\n]+\\).*\\(\\[[.0-9]+\\]\\)" svr)
-	       (setq snd (format "%s %s" (match-string 1 svr) (match-string 2 svr))))
+	   (if (string-match "from[ \t]+\\([^() \t\n]+\\).*\\([[][.0-9]+[]]\\)" svr)
+	       (setq snd (format "%s %s" (match-string 1 svr) (match-string 2 svr)))
+	     (if (string-match "from[ \t]+\\([^() \t\n]+\\)" svr)
+		 (setq snd (match-string 1 svr))))
 	   (when (and (string= snd "unknown")
 		      (string-match "from unknown (HELO \\([^() \t\n]+\\))" svr))
 	     (setq snd (concat (match-string 1 svr) "(unknown)"))))
@@ -572,11 +574,12 @@ If called with '\\[universal-argument]', it stays writable."
 	  (insert ":")
 	  (forward-char 2)
 	  (insert " (" (mew-time-tmzn-int) ") ")
-	  (if snd (insert snd))
+	  (if (and snd (not (string= snd last))) (insert snd))
 	  (insert " => ")
 	  (if rcv (insert rcv))
 	  (insert "\n")
-	  (setq snd nil rcv nil))))
+	  (setq last rcv)
+	  (setq snd "?" rcv "?"))))
      (mew-summary-display-postscript 'no-hook)
      (select-window win))))
 
@@ -787,7 +790,7 @@ over the window. Type '\\[mew-summary-prev-page]' to see them when a message is
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
