@@ -1675,7 +1675,7 @@ your POP server becomes non-zero. To use this feature,
 (defcustom mew-use-sender nil
   "*If From: contains multiple addresses, Mew adds Sender: anyway. 
 If From: contains one address and SMTP MAIL FROM
-('mew-smtp-mail-from') is different from it, this variable effects.
+\('mew-smtp-mail-from') is different from it, this variable effects.
 If non-nil, Mew adds Sender: and specifies SMTP MAIL FROM to its value.
 Otherwise, Mew does not add Sender:."
   :group 'mew-draft
@@ -1785,6 +1785,11 @@ For more information, see RFC 2595."
   :group 'mew-smtp
   :type 'boolean)
 
+(defcustom mew-use-punycode t
+  "*If non-nil, punycode strings are decoded into IDN strings"
+  :group 'mew-message
+  :type 'boolean)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Appearance
@@ -2762,7 +2767,13 @@ in Summary/Virtual mode."
   :type 'face)
 
 (defcustom mew-regex-url
-  "\\b\\(s?https?\\|ftp\\|file\\|gopher\\|news\\|telnet\\|wais\\|mailto\\):\\(//[-a-zA-Z0-9_.]+:[0-9]*\\)?[-a-zA-Z0-9_=?#$@~`%&*+|\\/.,:;]*[-a-zA-Z0-9_=#$@~`%&*+|\\/]"
+  (concat
+   "\\b\\("
+   "\\(\\(file\\|news\\|mailto\\):\\)"
+   "\\|"
+   "\\(\\(s?https?\\|ftp\\|gopher\\|telnet\\|wais\\)://\\)"
+   "\\)"
+   "[^ $B!!(B\t\n>)\"]+")
   "*Regular expression to find URL."
   :group 'mew-highlight
   :type 'regexp)
@@ -3186,7 +3197,7 @@ Level 2: syntax error."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2006 Mew developing team.
+;; Copyright (C) 1996-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
