@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Oct 24, 2006
+;; Revised: Jan 10, 2007
 
 ;;; Commentary:
 
@@ -18,7 +18,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "5.1.52"
+(defconst mew-version-number "5.2.50"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -125,13 +125,20 @@ A Draft buffer is prepared according to SWITCH-FUNCTION.
 CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
   (unless mew-init-p (mew-init))
   (let* ((draft (mew-folder-new-message mew-draft-folder))
-	 (attachdir (mew-attachdir draft)))
+	 (attachdir (mew-attachdir draft))
+	 cc asked)
+    (when (and mew-ask-to (null to))
+      (setq to (mew-input-address (concat mew-to: " ")))
+      (setq asked t))
+    (when mew-ask-cc
+      (setq cc (mew-input-address (concat mew-cc: " ")))
+      (setq asked t))
     (mew-current-set-window-config)
     (mew-window-configure 'draft)
     (mew-summary-prepare-draft
      (mew-draft-find-and-switch draft switch-function)
      (mew-delete-directory-recursively attachdir)
-     (mew-draft-header subject nil to nil nil nil nil other-headers)
+     (mew-draft-header subject nil to cc nil nil nil other-headers asked)
      (mew-draft-mode)
      (run-hooks 'mew-draft-mode-newdraft-hook))))
 
@@ -752,7 +759,7 @@ Mew remain, so you can resume with buffer operations."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2006 Mew developing team.
+;; Copyright (C) 1994-2007 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
